use color_eyre::Result;
use crossterm::event::{self, Event};
use ratatui::{DefaultTerminal, Frame};

fn render(frame: &mut Frame) {
    // Render the "hello world" widget to the terminal using the available area
    frame.render_widget("hello world", frame.area());
}

fn run(mut terminal: DefaultTerminal) -> Result<()> {
    // The main loop
    loop {
        // Draw the TUI by passing the render function to the terminal's draw method
        terminal.draw(render)?;

        // Listen for keypress events
        if matches!(event::read()?, Event::Key(_)) {
            // Break the loop on key-press and return Ok(())
            break Ok(());
        }
    }
}

fn main() -> Result<()> {
    color_eyre::install()?; // Colorful error messages

    let terminal = ratatui::init(); // Initialize the terminal to render the TUI
    let result = run(terminal); // The TUI app's main logic. The run() function above.

    ratatui::restore(); // Clear the terminal and return to the previous state

    result // Result of main()
}
